@@ -25,6 +25,7 @@ import copy
 from importlib import import_module
 import inspect
 import logging
+import operator
 import os
 
 from django.conf import settings
@@ -32,12 +33,10 @@ from django.conf.urls import include
 from django.conf.urls import url
 from django.core.exceptions import ImproperlyConfigured
 from django.urls import reverse
-from django.utils.encoding import python_2_unicode_compatible
 from django.utils.functional import empty
 from django.utils.functional import SimpleLazyObject
 from django.utils.module_loading import module_has_submodule
 from django.utils.translation import ugettext_lazy as _
-import six
 
 from horizon import conf
 from horizon.decorators import _current_component
@@ -52,15 +51,6 @@ from horizon.utils import settings as utils_settings
 DEFAULT_PANEL_GROUP = 'default'
 LOG = logging.getLogger(__name__)
 
-# Python 3.8 removes the ability to import the abstract base classes from
-# 'collections', but 'collections.abc' is not present in Python 2.7
-# TODO(stephenfin): Remove when we drop support for Python 2.7
-# pylint: disable=ungrouped-imports
-if hasattr(collections, 'abc'):
-    from collections.abc import Iterable
-else:
-    from collections import Iterable
-
 
 def _decorate_urlconf(urlpatterns, decorator, *args, **kwargs):
     for pattern in urlpatterns:
@@ -114,7 +104,6 @@ class NotRegistered(Exception):
     pass
 
 
-@python_2_unicode_compatible
 class HorizonComponent(object):
     policy_rules = tuple()
 
@@ -350,7 +339,6 @@ class Panel(HorizonComponent):
         return urlpatterns, self.slug, self.slug
 
 
-@six.python_2_unicode_compatible
 class PanelGroup(object):
     """A container for a set of :class:`~horizon.Panel` classes.
 
@@ -593,15 +581,15 @@ class Dashboard(Registry, HorizonComponent):
         panel_groups = []
         # If we have a flat iterable of panel names, wrap it again so
         # we have a consistent structure for the next step.
-        if all([isinstance(i, six.string_types) for i in self.panels]):
+        if all([isinstance(i, str) for i in self.panels]):
             self.panels = [self.panels]
 
         # Now iterate our panel sets.
         default_created = False
         for panel_set in self.panels:
             # Instantiate PanelGroup classes.
-            if not isinstance(panel_set, Iterable) and \
-                    issubclass(panel_set, PanelGroup):
+            if (not isinstance(panel_set, collections.abc.Iterable) and
+                    issubclass(panel_set, PanelGroup)):
                 panel_group = panel_set(self)
             # Check for nested tuples, and convert them to PanelGroups
             elif not isinstance(panel_set, PanelGroup):
@@ -779,7 +767,8 @@ class Site(Registry, HorizonComponent):
                 dashboards.append(dashboard)
                 registered.pop(dashboard.__class__)
             if registered:
-                extra = sorted(registered.values())
+                extra = sorted(registered.values(),
+                               key=operator.attrgetter('name'))
                 dashboards.extend(extra)
             return dashboards
         else:
@@ -824,7 +813,7 @@ class Site(Registry, HorizonComponent):
         if user_home:
             if callable(user_home):
                 return user_home(user)
-            elif isinstance(user_home, six.string_types):
+            elif isinstance(user_home, str):
                 # Assume we've got a URL if there's a slash in it
                 if '/' in user_home:
                     return user_home
