@@ -50,7 +50,7 @@ class InstanceViewTest(test.BaseAdminViewTests):
         res = self.client.get(INDEX_URL)
         self.assertTemplateUsed(res, INDEX_TEMPLATE)
         instances = res.context['table'].data
-        self.assertItemsEqual(instances, servers)
+        self.assertCountEqual(instances, servers)
 
         self.mock_extension_supported.assert_has_calls([
             mock.call('AdminActions', test.IsHttpRequest()),
@@ -94,7 +94,7 @@ class InstanceViewTest(test.BaseAdminViewTests):
 
         self.assertTemplateUsed(res, INDEX_TEMPLATE)
         instances = res.context['table'].data
-        self.assertItemsEqual(instances, servers)
+        self.assertCountEqual(instances, servers)
 
         search_opts = {'marker': None, 'paginate': True, 'all_tenants': True}
         self.mock_server_list_paged.assert_called_once_with(
@@ -143,7 +143,7 @@ class InstanceViewTest(test.BaseAdminViewTests):
         # there will be only one error message for all instances
         # (messages de-duplication).
         self.assertMessageCount(res, error=1)
-        self.assertItemsEqual(instances, servers)
+        self.assertCountEqual(instances, servers)
 
         self.mock_image_list_detailed_by_ids.assert_called_once_with(
             test.IsHttpRequest(), instances_img_ids)
@@ -487,7 +487,7 @@ class InstanceViewTest(test.BaseAdminViewTests):
         res = self.client.get(INDEX_URL)
         self.assertTemplateUsed(res, INDEX_TEMPLATE)
         instances = res.context['table'].data
-        self.assertItemsEqual(instances, [])
+        self.assertCountEqual(instances, [])
 
     @test.create_mocks({
         api.nova: ['flavor_list',
@@ -549,20 +549,20 @@ class InstanceViewTest(test.BaseAdminViewTests):
     @override_settings(API_RESULT_PAGE_SIZE=1)
     def test_severs_index_paginated(self):
         size = settings.API_RESULT_PAGE_SIZE
-        mox_servers = self.servers.list()
+        mock_servers = self.servers.list()
 
         # get first page
-        expected_servers = mox_servers[:size]
+        expected_servers = mock_servers[:size]
         res = self._test_servers_paginate_do(
             marker=None,
             servers=expected_servers,
             has_more=True,
             has_prev=False)
         servers = res.context['table'].data
-        self.assertItemsEqual(servers, expected_servers)
+        self.assertCountEqual(servers, expected_servers)
 
         # get second page
-        expected_servers = mox_servers[size:2 * size]
+        expected_servers = mock_servers[size:2 * size]
         marker = expected_servers[0].id
         res = self._test_servers_paginate_do(
             marker=marker,
@@ -570,10 +570,10 @@ class InstanceViewTest(test.BaseAdminViewTests):
             has_more=True,
             has_prev=True)
         servers = res.context['table'].data
-        self.assertItemsEqual(servers, expected_servers)
+        self.assertCountEqual(servers, expected_servers)
 
         # get last page
-        expected_servers = mox_servers[-size:]
+        expected_servers = mock_servers[-size:]
         marker = expected_servers[0].id
         res = self._test_servers_paginate_do(
             marker=marker,
@@ -581,16 +581,16 @@ class InstanceViewTest(test.BaseAdminViewTests):
             has_more=False,
             has_prev=True)
         servers = res.context['table'].data
-        self.assertItemsEqual(servers, expected_servers)
+        self.assertCountEqual(servers, expected_servers)
 
     @override_settings(API_RESULT_PAGE_SIZE=1)
     def test_servers_index_paginated_prev(self):
         size = settings.API_RESULT_PAGE_SIZE
-        mox_servers = self.servers.list()
+        mock_servers = self.servers.list()
 
         # prev from some page
-        expected_servers = mox_servers[size:2 * size]
-        marker = mox_servers[0].id
+        expected_servers = mock_servers[size:2 * size]
+        marker = mock_servers[0].id
 
         res = self._test_servers_paginate_do(
             marker=marker,
@@ -598,15 +598,15 @@ class InstanceViewTest(test.BaseAdminViewTests):
             has_more=False,
             has_prev=True)
         servers = res.context['table'].data
-        self.assertItemsEqual(servers, expected_servers)
+        self.assertCountEqual(servers, expected_servers)
 
         # back to first page
-        expected_servers = mox_servers[:size]
-        marker = mox_servers[0].id
+        expected_servers = mock_servers[:size]
+        marker = mock_servers[0].id
         res = self._test_servers_paginate_do(
             marker=marker,
             servers=expected_servers,
             has_more=True,
             has_prev=False)
         servers = res.context['table'].data
-        self.assertItemsEqual(servers, expected_servers)
+        self.assertCountEqual(servers, expected_servers)
