@@ -16,7 +16,6 @@ import copy
 from django.urls import reverse
 
 import mock
-import six
 
 from openstack_dashboard import api
 from openstack_dashboard.test import helpers as test
@@ -99,7 +98,7 @@ class RouterTestCase(object):
 
         self.assertTemplateUsed(res, INDEX_TEMPLATE)
         routers = res.context['table'].data
-        self.assertItemsEqual(routers, self.routers.list())
+        self.assertCountEqual(routers, self.routers.list())
 
         self.mock_router_list.assert_called_once_with(
             test.IsHttpRequest(), tenant_id=self.tenant.id)
@@ -176,7 +175,7 @@ class RouterTestCase(object):
 
         self.assertTemplateUsed(res, 'horizon/common/_detail.html')
         ports = res.context['interfaces_table'].data
-        self.assertItemsEqual(ports, [self.ports.first()])
+        self.assertCountEqual(ports, [self.ports.first()])
 
         self._check_get_detail(router)
 
@@ -1070,7 +1069,7 @@ class RouterRouteTestCase(object):
         self.assertTemplateUsed(res, 'horizon/common/_detail.html')
         routes = res.context['extra_routes_table'].data
         routes_dict = [r._apidict for r in routes]
-        self.assertItemsEqual(routes_dict, router['routes'])
+        self.assertCountEqual(routes_dict, router['routes'])
 
         self._check_get_detail(router, extraroute=True)
 
@@ -1188,7 +1187,7 @@ class RouterViewTests(RouterMixin, test.TestCase):
         self.assertTemplateUsed(res, INDEX_TEMPLATE)
 
         routers = res.context['routers_table'].data
-        self.assertItemsEqual(routers, self.routers.list())
+        self.assertCountEqual(routers, self.routers.list())
 
         create_action = self.getAndAssertTableAction(res, 'routers', 'create')
         self.assertIn('disabled', create_action.classes,
@@ -1221,7 +1220,7 @@ class RouterViewTests(RouterMixin, test.TestCase):
         self.assertTemplateUsed(res, INDEX_TEMPLATE)
 
         routers = res.context['routers_table'].data
-        self.assertItemsEqual(routers, self.routers.list())
+        self.assertCountEqual(routers, self.routers.list())
 
         create_action = self.getAndAssertTableAction(res, 'routers', 'create')
         self.assertFalse('disabled' in create_action.classes,
@@ -1254,12 +1253,11 @@ class RouterViewTests(RouterMixin, test.TestCase):
         self.assertTemplateUsed(res, INDEX_TEMPLATE)
 
         routers = res.context['routers_table'].data
-        self.assertItemsEqual(routers, self.routers.list())
+        self.assertCountEqual(routers, self.routers.list())
 
         create_action = self.getAndAssertTableAction(res, 'routers', 'create')
         self.assertEqual(set(['ajax-modal']), set(create_action.classes))
-        self.assertEqual('Create Router',
-                         six.text_type(create_action.verbose_name))
+        self.assertEqual('Create Router', create_action.verbose_name)
         self.assertEqual('horizon:project:routers:create', create_action.url)
         self.assertEqual((('network', 'create_router'),),
                          create_action.policy_rules)
