@@ -17,14 +17,12 @@
 #    under the License.
 
 from django.conf import settings
-from django.core.urlresolvers import reverse
-from django import http
 from django.test.utils import override_settings
+from django.urls import reverse
 from django.utils.http import urlunquote
-from mox3.mox import IsA
+import mock
 
 from openstack_dashboard import api
-from openstack_dashboard.api import cinder
 from openstack_dashboard.dashboards.project.snapshots \
     import tables as snapshot_tables
 from openstack_dashboard.test import helpers as test
@@ -35,47 +33,55 @@ INDEX_URL = reverse('horizon:project:snapshots:index')
 
 
 class VolumeSnapshotsViewTests(test.TestCase):
-    @test.create_stubs({api.cinder: ('tenant_absolute_limits',
-                                     'volume_snapshot_list_paged',
-                                     'volume_list',),
+    @test.create_mocks({api.cinder: ('volume_snapshot_list_paged',
+                                     'volume_list',
+                                     'group_snapshot_list'),
                         api.base: ('is_service_enabled',)})
     def _test_snapshots_index_paginated(self, marker, sort_dir, snapshots, url,
-                                        has_more, has_prev):
-        api.base.is_service_enabled(IsA(http.HttpRequest), 'volumev3') \
-            .AndReturn(True)
-        api.base.is_service_enabled(IsA(http.HttpRequest), 'volumev3') \
-            .AndReturn(True)
-        api.cinder.volume_snapshot_list_paged(
-            IsA(http.HttpRequest), marker=marker, sort_dir=sort_dir,
-            paginate=True).AndReturn([snapshots, has_more, has_prev])
-        api.cinder.volume_list(IsA(http.HttpRequest)).AndReturn(
-            self.cinder_volumes.list())
-        self.mox.ReplayAll()
+                                        has_more, has_prev, with_groups=False):
+        self.mock_is_service_enabled.return_value = True
+        self.mock_volume_snapshot_list_paged.return_value = [snapshots,
+                                                             has_more,
+                                                             has_prev]
+        self.mock_volume_list.return_value = self.cinder_volumes.list()
+        self.mock_group_snapshot_list.return_value = \
+            self.cinder_volume_snapshots_with_groups.list()
 
         res = self.client.get(urlunquote(url))
         self.assertEqual(res.status_code, 200)
         self.assertTemplateUsed(res, 'horizon/common/_data_table_view.html')
 
-        self.mox.UnsetStubs()
+        self.assert_mock_multiple_calls_with_same_arguments(
+            self.mock_is_service_enabled, 2,
+            mock.call(test.IsHttpRequest(), 'volumev3'))
+        self.mock_volume_snapshot_list_paged.assert_called_once_with(
+            test.IsHttpRequest(), marker=marker, sort_dir=sort_dir,
+            paginate=True)
+        self.mock_volume_list.assert_called_once_with(test.IsHttpRequest())
+
+        if with_groups:
+            self.mock_group_snapshot_list.assert_called_once_with(
+                test.IsHttpRequest())
+
         return res
 
     @override_settings(API_RESULT_PAGE_SIZE=1)
     def test_snapshots_index_paginated(self):
-        mox_snapshots = self.cinder_volume_snapshots.list()
+        mock_snapshots = self.cinder_volume_snapshots.list()
         size = settings.API_RESULT_PAGE_SIZE
         base_url = INDEX_URL
         next = snapshot_tables.VolumeSnapshotsTable._meta.pagination_param
 
         # get first page
-        expected_snapshots = mox_snapshots[:size]
+        expected_snapshots = mock_snapshots[:size]
         res = self._test_snapshots_index_paginated(
             marker=None, sort_dir="desc", snapshots=expected_snapshots,
             url=base_url, has_more=True, has_prev=False)
         snapshots = res.context['volume_snapshots_table'].data
-        self.assertItemsEqual(snapshots, expected_snapshots)
+        self.assertCountEqual(snapshots, expected_snapshots)
 
         # get second page
-        expected_snapshots = mox_snapshots[size:2 * size]
+        expected_snapshots = mock_snapshots[size:2 * size]
         marker = expected_snapshots[0].id
 
         url = base_url + "?%s=%s" % (next, marker)
@@ -83,81 +89,86 @@ class VolumeSnapshotsViewTests(test.TestCase):
             marker=marker, sort_dir="desc", snapshots=expected_snapshots,
             url=url, has_more=True, has_prev=True)
         snapshots = res.context['volume_snapshots_table'].data
-        self.assertItemsEqual(snapshots, expected_snapshots)
+        self.assertCountEqual(snapshots, expected_snapshots)
 
         # get last page
-        expected_snapshots = mox_snapshots[-size:]
+        expected_snapshots = mock_snapshots[-size:]
         marker = expected_snapshots[0].id
         url = base_url + "?%s=%s" % (next, marker)
         res = self._test_snapshots_index_paginated(
             marker=marker, sort_dir="desc", snapshots=expected_snapshots,
             url=url, has_more=False, has_prev=True)
         snapshots = res.context['volume_snapshots_table'].data
-        self.assertItemsEqual(snapshots, expected_snapshots)
+        self.assertCountEqual(snapshots, expected_snapshots)
+
+    @override_settings(API_RESULT_PAGE_SIZE=1)
+    def test_snapshots_index_with_group(self):
+        mock_snapshots = self.cinder_volume_snapshots_with_groups.list()
+        size = settings.API_RESULT_PAGE_SIZE
+        base_url = INDEX_URL
+
+        # get first page
+        expected_snapshots = mock_snapshots[:size]
+        res = self._test_snapshots_index_paginated(
+            marker=None, sort_dir="desc", snapshots=expected_snapshots,
+            url=base_url, has_more=False, has_prev=False, with_groups=True)
+        snapshots = res.context['volume_snapshots_table'].data
+        self.assertCountEqual(snapshots, mock_snapshots)
 
     @override_settings(API_RESULT_PAGE_SIZE=1)
     def test_snapshots_index_paginated_prev_page(self):
-        mox_snapshots = self.cinder_volume_snapshots.list()
+        mock_snapshots = self.cinder_volume_snapshots.list()
         size = settings.API_RESULT_PAGE_SIZE
         base_url = INDEX_URL
         prev = snapshot_tables.VolumeSnapshotsTable._meta.prev_pagination_param
 
         # prev from some page
-        expected_snapshots = mox_snapshots[size:2 * size]
+        expected_snapshots = mock_snapshots[size:2 * size]
         marker = expected_snapshots[0].id
         url = base_url + "?%s=%s" % (prev, marker)
         res = self._test_snapshots_index_paginated(
             marker=marker, sort_dir="asc", snapshots=expected_snapshots,
             url=url, has_more=True, has_prev=True)
         snapshots = res.context['volume_snapshots_table'].data
-        self.assertItemsEqual(snapshots, expected_snapshots)
+        self.assertCountEqual(snapshots, expected_snapshots)
 
         # back to first page
-        expected_snapshots = mox_snapshots[:size]
+        expected_snapshots = mock_snapshots[:size]
         marker = expected_snapshots[0].id
         url = base_url + "?%s=%s" % (prev, marker)
         res = self._test_snapshots_index_paginated(
             marker=marker, sort_dir="asc", snapshots=expected_snapshots,
             url=url, has_more=True, has_prev=False)
         snapshots = res.context['volume_snapshots_table'].data
-        self.assertItemsEqual(snapshots, expected_snapshots)
+        self.assertCountEqual(snapshots, expected_snapshots)
 
-    @test.create_stubs({cinder: ('volume_get',),
-                        quotas: ('tenant_limit_usages',)})
+    @test.create_mocks({api.cinder: ('volume_get',),
+                        quotas: ('tenant_quota_usages',)})
     def test_create_snapshot_get(self):
         volume = self.cinder_volumes.first()
-        cinder.volume_get(IsA(http.HttpRequest), volume.id) \
-            .AndReturn(volume)
-        snapshot_used = len(self.cinder_volume_snapshots.list())
-        usage_limit = {'maxTotalVolumeGigabytes': 250,
-                       'totalGigabytesUsed': 20,
-                       'totalSnapshotsUsed': snapshot_used,
-                       'maxTotalSnapshots': 6}
-        quotas.tenant_limit_usages(IsA(http.HttpRequest)).\
-            AndReturn(usage_limit)
-        self.mox.ReplayAll()
+        self.mock_volume_get.return_value = volume
+        self.mock_tenant_quota_usages.return_value = \
+            self.cinder_quota_usages.first()
 
         url = reverse('horizon:project:volumes:create_snapshot',
                       args=[volume.id])
         res = self.client.get(url)
 
         self.assertTemplateUsed(res, 'project/volumes/create_snapshot.html')
+        self.mock_volume_get.assert_called_once_with(test.IsHttpRequest(),
+                                                     volume.id)
+        self.mock_tenant_quota_usages.assert_called_once_with(
+            test.IsHttpRequest(),
+            targets=('snapshots', 'gigabytes'))
 
-    @test.create_stubs({cinder: ('volume_get',
-                                 'volume_snapshot_create',)})
+    @test.create_mocks({api.cinder: ('volume_get',
+                                     'volume_snapshot_create')})
     def test_create_snapshot_post(self):
         volume = self.cinder_volumes.first()
         snapshot = self.cinder_volume_snapshots.first()
 
-        cinder.volume_get(IsA(http.HttpRequest), volume.id) \
-            .AndReturn(volume)
-        cinder.volume_snapshot_create(IsA(http.HttpRequest),
-                                      volume.id,
-                                      snapshot.name,
-                                      snapshot.description,
-                                      force=False) \
-            .AndReturn(snapshot)
-        self.mox.ReplayAll()
+        self.mock_volume_get.return_value = volume
+        self.mock_volume_snapshot_create.return_value = snapshot
 
         formData = {'method': 'CreateSnapshotForm',
                     'tenant_id': self.tenant.id,
@@ -169,21 +180,23 @@ class VolumeSnapshotsViewTests(test.TestCase):
         res = self.client.post(url, formData)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
-    @test.create_stubs({cinder: ('volume_get',
-                                 'volume_snapshot_create',)})
+        self.mock_volume_get.assert_called_once_with(test.IsHttpRequest(),
+                                                     volume.id)
+        self.mock_volume_snapshot_create.assert_called_once_with(
+            test.IsHttpRequest(),
+            volume.id,
+            snapshot.name,
+            snapshot.description,
+            force=False)
+
+    @test.create_mocks({api.cinder: ('volume_get',
+                                     'volume_snapshot_create')})
     def test_force_create_snapshot(self):
         volume = self.cinder_volumes.get(name='my_volume')
         snapshot = self.cinder_volume_snapshots.first()
 
-        cinder.volume_get(IsA(http.HttpRequest), volume.id) \
-            .AndReturn(volume)
-        cinder.volume_snapshot_create(IsA(http.HttpRequest),
-                                      volume.id,
-                                      snapshot.name,
-                                      snapshot.description,
-                                      force=True) \
-            .AndReturn(snapshot)
-        self.mox.ReplayAll()
+        self.mock_volume_get.return_value = volume
+        self.mock_volume_snapshot_create.return_value = snapshot
 
         formData = {'method': 'CreateSnapshotForm',
                     'tenant_id': self.tenant.id,
@@ -195,23 +208,27 @@ class VolumeSnapshotsViewTests(test.TestCase):
         res = self.client.post(url, formData)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
-    @test.create_stubs({api.cinder: ('volume_snapshot_list_paged',
+        self.mock_volume_get.assert_called_once_with(test.IsHttpRequest(),
+                                                     volume.id)
+        self.mock_volume_snapshot_create.assert_called_once_with(
+            test.IsHttpRequest(),
+            volume.id,
+            snapshot.name,
+            snapshot.description,
+            force=True)
+
+    @test.create_mocks({api.cinder: ('volume_snapshot_list_paged',
                                      'volume_list',
-                                     'volume_snapshot_delete',
-                                     'tenant_absolute_limits')})
+                                     'volume_snapshot_delete')})
     def test_delete_volume_snapshot(self):
         vol_snapshots = self.cinder_volume_snapshots.list()
         volumes = self.cinder_volumes.list()
         snapshot = self.cinder_volume_snapshots.first()
 
-        api.cinder.volume_snapshot_list_paged(
-            IsA(http.HttpRequest), paginate=True, marker=None,
-            sort_dir='desc').AndReturn([vol_snapshots, False, False])
-        api.cinder.volume_list(IsA(http.HttpRequest)). \
-            AndReturn(volumes)
-
-        api.cinder.volume_snapshot_delete(IsA(http.HttpRequest), snapshot.id)
-        self.mox.ReplayAll()
+        self.mock_volume_snapshot_list_paged.return_value = [vol_snapshots,
+                                                             False, False]
+        self.mock_volume_list.return_value = volumes
+        self.mock_volume_snapshot_delete.return_value = None
 
         formData = {'action': 'volume_snapshots__delete__%s' % snapshot.id}
         res = self.client.post(INDEX_URL, formData)
@@ -219,19 +236,20 @@ class VolumeSnapshotsViewTests(test.TestCase):
         self.assertRedirectsNoFollow(res, INDEX_URL)
         self.assertMessageCount(success=1)
 
-    @test.create_stubs({api.cinder: ('volume_snapshot_get', 'volume_get')})
+        self.mock_volume_snapshot_list_paged.assert_called_once_with(
+            test.IsHttpRequest(), paginate=True, marker=None, sort_dir='desc')
+        self.mock_volume_list.assert_called_once_with(test.IsHttpRequest())
+        self.mock_volume_snapshot_delete.assert_called_once_with(
+            test.IsHttpRequest(), snapshot.id)
+
+    @test.create_mocks({api.cinder: ('volume_get',
+                                     'volume_snapshot_get')})
     def test_volume_snapshot_detail_get(self):
         volume = self.cinder_volumes.first()
         snapshot = self.cinder_volume_snapshots.first()
 
-        api.cinder.volume_get(IsA(http.HttpRequest), volume.id). \
-            AndReturn(volume)
-        api.cinder.volume_snapshot_get(IsA(http.HttpRequest), snapshot.id). \
-            AndReturn(snapshot)
-        api.cinder.volume_get(IsA(http.HttpRequest), snapshot.volume_id). \
-            AndReturn(volume)
-
-        self.mox.ReplayAll()
+        self.mock_volume_get.return_value = volume
+        self.mock_volume_snapshot_get.return_value = snapshot
 
         url = reverse('horizon:project:snapshots:detail',
                       args=[snapshot.id])
@@ -240,14 +258,20 @@ class VolumeSnapshotsViewTests(test.TestCase):
         self.assertTemplateUsed(res, 'horizon/common/_detail.html')
         self.assertEqual(res.context['snapshot'].id, snapshot.id)
 
-    @test.create_stubs({api.cinder: ('volume_snapshot_get',)})
+        self.mock_volume_get.assert_has_calls([
+            mock.call(test.IsHttpRequest(), volume.id),
+            mock.call(test.IsHttpRequest(), snapshot.volume_id),
+        ])
+        self.assertEqual(2, self.mock_volume_get.call_count)
+        self.mock_volume_snapshot_get.assert_called_once_with(
+            test.IsHttpRequest(), snapshot.id)
+
+    @test.create_mocks({api.cinder: ('volume_snapshot_get',)})
     def test_volume_snapshot_detail_get_with_exception(self):
         # Test to verify redirect if get volume snapshot fails
         snapshot = self.cinder_volume_snapshots.first()
 
-        api.cinder.volume_snapshot_get(IsA(http.HttpRequest), snapshot.id).\
-            AndRaise(self.exceptions.cinder)
-        self.mox.ReplayAll()
+        self.mock_volume_snapshot_get.side_effect = self.exceptions.cinder
 
         url = reverse('horizon:project:snapshots:detail',
                       args=[snapshot.id])
@@ -255,38 +279,36 @@ class VolumeSnapshotsViewTests(test.TestCase):
 
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
-    @test.create_stubs({api.cinder: ('volume_snapshot_get', 'volume_get')})
+        self.mock_volume_snapshot_get.assert_called_once_with(
+            test.IsHttpRequest(), snapshot.id)
+
+    @test.create_mocks({api.cinder: ('volume_get',
+                                     'volume_snapshot_get')})
     def test_volume_snapshot_detail_with_volume_get_exception(self):
         # Test to verify redirect if get volume fails
         volume = self.cinder_volumes.first()
         snapshot = self.cinder_volume_snapshots.first()
 
-        api.cinder.volume_get(IsA(http.HttpRequest), volume.id). \
-            AndRaise(self.exceptions.cinder)
-        api.cinder.volume_snapshot_get(IsA(http.HttpRequest), snapshot.id). \
-            AndReturn(snapshot)
-
-        self.mox.ReplayAll()
+        self.mock_volume_get.side_effect = self.exceptions.cinder
+        self.mock_volume_snapshot_get.return_value = snapshot
 
         url = reverse('horizon:project:snapshots:detail',
                       args=[snapshot.id])
         res = self.client.get(url)
 
         self.assertRedirectsNoFollow(res, INDEX_URL)
+        self.mock_volume_get.assert_called_once_with(test.IsHttpRequest(),
+                                                     volume.id)
+        self.mock_volume_snapshot_get.assert_called_once_with(
+            test.IsHttpRequest(), snapshot.id)
 
-    @test.create_stubs({cinder: ('volume_snapshot_update',
-                                 'volume_snapshot_get')})
+    @test.create_mocks({api.cinder: ('volume_snapshot_update',
+                                     'volume_snapshot_get')})
     def test_update_snapshot(self):
         snapshot = self.cinder_volume_snapshots.first()
 
-        cinder.volume_snapshot_get(IsA(http.HttpRequest), snapshot.id) \
-            .AndReturn(snapshot)
-        cinder.volume_snapshot_update(IsA(http.HttpRequest),
-                                      snapshot.id,
-                                      snapshot.name,
-                                      snapshot.description) \
-            .AndReturn(snapshot)
-        self.mox.ReplayAll()
+        self.mock_volume_snapshot_get.return_value = snapshot
+        self.mock_volume_snapshot_update.return_value = snapshot
 
         formData = {'method': 'UpdateSnapshotForm',
                     'name': snapshot.name,
@@ -295,3 +317,11 @@ class VolumeSnapshotsViewTests(test.TestCase):
                       args=[snapshot.id])
         res = self.client.post(url, formData)
         self.assertRedirectsNoFollow(res, INDEX_URL)
+
+        self.mock_volume_snapshot_get.assert_called_once_with(
+            test.IsHttpRequest(), snapshot.id)
+        self.mock_volume_snapshot_update.assert_called_once_with(
+            test.IsHttpRequest(),
+            snapshot.id,
+            snapshot.name,
+            snapshot.description)
