@@ -12,10 +12,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from urllib.parse import urlsplit
+
 from django.conf import settings
-from django.core.urlresolvers import reverse
 from django import http
-from django.utils.six.moves.urllib.parse import urlsplit
+from django.urls import reverse
 
 import mock
 
