@@ -17,7 +17,7 @@
 #    under the License.
 
 from functools import wraps
-from importlib import import_module
+import importlib
 import logging
 import os
 import traceback
@@ -34,8 +34,6 @@ import mock
 from openstack_auth import user
 from openstack_auth import utils
 from requests.packages.urllib3.connection import HTTPConnection
-import six
-from six import moves
 
 from horizon import base
 from horizon import conf
@@ -273,7 +271,7 @@ class TestCase(horizon_helpers.TestCase):
         Asserts that the given response issued a 302 redirect without
         processing the view which is redirected to.
         """
-        loc = six.text_type(response._headers.get('location', None)[1])
+        loc = str(response._headers.get('location', None)[1])
         loc = http.urlunquote(loc)
         expected_url = http.urlunquote(expected_url)
         self.assertEqual(loc, expected_url)
@@ -308,7 +306,7 @@ class TestCase(horizon_helpers.TestCase):
             assert len(errors) == count, \
                 "%d errors were found on the form, %d expected" % \
                 (len(errors), count)
-            if message and message not in six.text_type(errors):
+            if message and message not in str(errors):
                 self.fail("Expected message not found, instead found: %s"
                           % ["%s: %s" % (key, [e for e in field_errors]) for
                              (key, field_errors) in errors.items()])
@@ -332,13 +330,11 @@ class TestCase(horizon_helpers.TestCase):
     def getAndAssertTableRowAction(self, response, table_name,
                                    action_name, row_id):
         table = response.context[table_name + '_table']
-        rows = list(moves.filter(lambda x: x.id == row_id,
-                                 table.data))
+        rows = list(filter(lambda x: x.id == row_id, table.data))
         self.assertEqual(1, len(rows),
                          "Did not find a row matching id '%s'" % row_id)
         row_actions = table.get_row_actions(rows[0])
-        actions = list(moves.filter(lambda x: x.name == action_name,
-                                    row_actions))
+        actions = list(filter(lambda x: x.name == action_name, row_actions))
 
         msg_args = (action_name, table_name, row_id)
         self.assertGreater(
@@ -356,8 +352,7 @@ class TestCase(horizon_helpers.TestCase):
 
         table = response.context[table_name + '_table']
         table_actions = table.get_table_actions()
-        actions = list(moves.filter(lambda x: x.name == action_name,
-                                    table_actions))
+        actions = list(filter(lambda x: x.name == action_name, table_actions))
         msg_args = (action_name, table_name)
         self.assertGreater(
             len(actions), 0,
@@ -419,7 +414,7 @@ class TestCase(horizon_helpers.TestCase):
                 count, len(errors),
                 "%d errors were found on the workflow, %d expected" %
                 (len(errors), count))
-            if message and message not in six.text_type(errors):
+            if message and message not in str(errors):
                 self.fail("Expected message not found, instead found: %s"
                           % ["%s: %s" % (key, [e for e in field_errors]) for
                              (key, field_errors) in errors.items()])
@@ -441,7 +436,7 @@ class BaseAdminViewTests(TestCase):
 
     def setSessionValues(self, **kwargs):
         settings.SESSION_ENGINE = 'django.contrib.sessions.backends.file'
-        engine = import_module(settings.SESSION_ENGINE)
+        engine = importlib.import_module(settings.SESSION_ENGINE)
         store = engine.SessionStore()
         for key in kwargs:
             store[key] = kwargs[key]
@@ -572,7 +567,7 @@ class PluginTestCase(TestCase):
         del base.Horizon
         base.Horizon = base.HorizonSite()
         # Reload the convenience references to Horizon stored in __init__
-        moves.reload_module(import_module("horizon"))
+        importlib.reload(importlib.import_module("horizon"))
         # Re-register our original dashboards and panels.
         # This is necessary because autodiscovery only works on the first
         # import, and calling reload introduces innumerable additional
@@ -592,7 +587,7 @@ class PluginTestCase(TestCase):
         only for testing and should never be used on a live site.
         """
         urls.clear_url_caches()
-        moves.reload_module(import_module(settings.ROOT_URLCONF))
+        importlib.reload(importlib.import_module(settings.ROOT_URLCONF))
         base.Horizon._urls()
 
 
